==> okteta-14.12.1.tar.xz: okteta-14.12.1/kasten/gui/io/streamencoder/srec/bytearraysrecstreamencoderconfigeditor.h <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2010 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef BYTEARRAYSRECSTREAMENCODERCONFIGEDITOR_H
#define BYTEARRAYSRECSTREAMENCODERCONFIGEDITOR_H

// lib
#include "bytearraysrecstreamencoder.h"
// Qt
#include <abstractmodelstreamencoderconfigeditor.h>

class KComboBox;


namespace Kasten
{

class ByteArraySRecStreamEncoderConfigEditor : public AbstractModelStreamEncoderConfigEditor
{
  Q_OBJECT

  public:
    explicit ByteArraySRecStreamEncoderConfigEditor( ByteArraySRecStreamEncoder* encoder, QWidget* parent = 0 );
    virtual ~ByteArraySRecStreamEncoderConfigEditor();

  public: // AbstractModelStreamEncoderConfigEditor API
    virtual AbstractSelectionView* createPreviewView() const;

  protected Q_SLOTS:
    void onSettingsChanged();

  protected:
    ByteArraySRecStreamEncoder* mEncoder;
    SRecStreamEncoderSettings mSettings;

    KComboBox* mAddressSizeSelect;
};

}

#endif

==> okteta-16.04.0.tar.xz: okteta-16.04.0/kasten/gui/io/streamencoder/srec/bytearraysrecstreamencoderconfigeditor.h <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2010 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef BYTEARRAYSRECSTREAMENCODERCONFIGEDITOR_H
#define BYTEARRAYSRECSTREAMENCODERCONFIGEDITOR_H

// lib
#include "bytearraysrecstreamencoder.h"
// Kasten gui
#include <kasten/abstractmodelstreamencoderconfigeditor.h>

class KComboBox;


namespace Kasten
{

class ByteArraySRecStreamEncoderConfigEditor : public AbstractModelStreamEncoderConfigEditor
{
  Q_OBJECT

  public:
    explicit ByteArraySRecStreamEncoderConfigEditor( ByteArraySRecStreamEncoder* encoder, QWidget* parent = 0 );
    virtual ~ByteArraySRecStreamEncoderConfigEditor();

  public: // AbstractModelStreamEncoderConfigEditor API
    virtual AbstractSelectionView* createPreviewView() const;

  protected Q_SLOTS:
    void onSettingsChanged();

  protected:
    ByteArraySRecStreamEncoder* mEncoder;
    SRecStreamEncoderSettings mSettings;

    KComboBox* mAddressSizeSelect;
};

}

#endif
